summaryrefslogtreecommitdiffstats
path: root/chrome/browser/extensions/error_console/error_console.h
diff options
context:
space:
mode:
authorrdevlin.cronin <rdevlin.cronin@chromium.org>2015-03-13 10:35:18 -0700
committerCommit bot <commit-bot@chromium.org>2015-03-13 17:35:53 +0000
commit820b1477f4b0aeebedd23fd1f651380b0527d89f (patch)
tree718d2d715db5d01a829de7a5e2ea6b7ace66506d /chrome/browser/extensions/error_console/error_console.h
parent1375d6aec85f1707956e60d752648d50aace5562 (diff)
downloadchromium_src-820b1477f4b0aeebedd23fd1f651380b0527d89f.zip
chromium_src-820b1477f4b0aeebedd23fd1f651380b0527d89f.tar.gz
chromium_src-820b1477f4b0aeebedd23fd1f651380b0527d89f.tar.bz2
[Extensions] Update extensions ui to use developerPrivate.getExtensionsInfo
Update the chrome extensions page to use developerPrivate.getExtensionsInfo method to retrieve extensions info. Remove now-unneeded code from ExtensionSettingsHandler. Update various js files to use more closure-compiler-y stuff. Migrate tests for generating extension info, and add more of them. BUG=461039 Review URL: https://codereview.chromium.org/1008593002 Cr-Commit-Position: refs/heads/master@{#320519}
Diffstat (limited to 'chrome/browser/extensions/error_console/error_console.h')
-rw-r--r--chrome/browser/extensions/error_console/error_console.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/chrome/browser/extensions/error_console/error_console.h b/chrome/browser/extensions/error_console/error_console.h
index 23c522b..9d612de 100644
--- a/chrome/browser/extensions/error_console/error_console.h
+++ b/chrome/browser/extensions/error_console/error_console.h
@@ -17,6 +17,7 @@
#include "extensions/browser/extension_registry_observer.h"
namespace content {
+class BrowserContext;
class NotificationDetails;
class NotificationSource;
class RenderViewHost;
@@ -51,8 +52,8 @@ class ErrorConsole : public content::NotificationObserver,
explicit ErrorConsole(Profile* profile);
~ErrorConsole() override;
- // Convenience method to return the ErrorConsole for a given profile.
- static ErrorConsole* Get(Profile* profile);
+ // Convenience method to return the ErrorConsole for a given |context|.
+ static ErrorConsole* Get(content::BrowserContext* context);
// Set whether or not errors of the specified |type| are stored for the
// extension with the given |extension_id|. This will be stored in the